@@ -20,6 +20,7 @@
 #==============================================================================
 # Imports standards
 #==============================================================================
+from os import linesep
 from os.path import exists, abspath, isdir, isfile, expanduser
 from optparse import OptionParser
 import sys
@@ -29,7 +30,7 @@ class Options:
 
     def __init__(self):
         self._options = ()
-        parser = OptionParser(version="%prog 0.8")
+        parser = OptionParser(version="%prog 0.9")
         self.definit_options(parser)
         self.teste_options()
 
@@ -37,16 +38,16 @@ class Options:
         """Définition des options"""
         parser.add_option("-e", "--entree", dest="nomfichier",
             action="store", type="string",
-            help=u"contient les ordres pour générer le ou les scripts",
-            metavar="FICHIER")
+            help=_("contains the orders to generate the script"),
+            metavar=_("FILE"))
         parser.add_option("-s", "--repertoire-sortie", dest="repsortie",
             action="store", type="string",
-            help=u"répertoire où entreposer les fichiers générés",
-            metavar=u"RÉPERTOIRE")
+            help=_("the directory to store generated scripts"),
+            metavar=_("DIRECTORY"))
         parser.add_option("-d", "--delai", dest="delai",
             action="store", type="int", default=2,
-            help=u"en secondes pour exécuter une commande du script",
-            metavar=u"DÉLAI")
+            help=_("in seconds the time between each order execution"),
+            metavar=_("DELAY"))
         self._options = parser.parse_args()
 
     def teste_options(self):
@@ -54,10 +55,10 @@ class Options:
         if self._options[0].nomfichier is not None:
             fichierentree = abspath(expanduser(self._options[0].nomfichier))
             if not exists(fichierentree):
-                print "Le fichier %s n'existe pas." % fichierentree
+                print _("%s : no such file") % fichierentree
                 sys.exit(1)
             elif not isfile(fichierentree):
-                print "%s n'est pas un fichier." % fichierentree
+                print _("%s is not a file") % fichierentree
                 sys.exit(1)
             else:
                 self._options[0].nomfichier = fichierentree
@@ -65,10 +66,10 @@ class Options:
         if self._options[0].repsortie is not None:
             repertoiresortie = abspath(expanduser(self._options[0].repsortie))
             if not exists(repertoiresortie):
-                print "Le répertoire %s n'existe pas." % repertoiresortie
+                print _("%s : no such directory") % repertoiresortie
                 sys.exit(1)
             elif not isdir(repertoiresortie):
-                print "%s n'est pas un répertoire." % repertoiresortie
+                print _("%s is not a directory") % repertoiresortie
                 sys.exit(1)
             else:
                 self._options[0].repsortie = repertoiresortie    
@@ -76,8 +77,8 @@ class Options:
         if self._options[0].delai is not None:
             if self._options[0].delai < -1 or \
 				self._options[0].delai > sys.maxint:
-                print "La valeur indiqué n'est pas valide.\nLa valeur délai \
-doit être >= -1 et <= valeur d'un entier sur votre système."
+                print _("The given value is not valid%sThe delay value \
+must be >= -1 and <= value of an integer on your system" % linesep)
                 sys.exit(1)
             
     def lesoptions(self):
