@@ -59,36 +59,40 @@ class Terminal:
             print message
             sys.exit(1)
         except KeyboardInterrupt:
-            print "Bélier a été arrêté manuellement par l'utilisateur."
+            print _("Belier has been stopped manually by the user")
             sys.exit(1)
         for boucle in xrange(2):
             for num in xrange(len(self._ordres)):
-                if boucle == 0:
+                if boucle == 0 and self._ordres[num] != linesep:
                     if '\0' in self._ordres[num]:
-                        print "Format du fichier d'ordres invalide. \
-Peut-être un fichier binaire ?"
+                        print _("The file format is invalid \
+It may be a binary file ?")
                         sys.exit(1)
                     self._ordres[num] = self.remplace_guillemets_motdepasse(
                                                             self._ordres[num]) 
                     if len(self._ordres[num].split(' ')) > 5:
-                        print "Nombre invalide d'arguments \
-sur la ligne du fichier d'ordres"
+                        print _("Incorrect argument number \
+on the order file line")
                         sys.exit(1)
                     identifiant = self._ordres[num].split(' ')[0]
                     if len(identifiant) <= 2 and identifiant != linesep:
-                        print "Un nom d'hôte doit contenir au \
-moins deux caractères (rfc952)"
+                        print _("A hostname must contain at \
+least two characters (rfc952)")
                         sys.exit(1)
                     ipoudns = identifiant.split('@')[-1]
                     if len(ipoudns) > 255:
-                        print 'La taille de votre nom de domaine \
-dépasse 255 caractères'
+                        print _('Your domain name size \
+exceeds 255 characters')
                         sys.exit(1)
                     for hostname in ipoudns.split('.'):
                         if len(hostname) > 64:
-                            print "La taille de votre nom d'hôte \
-dépasse 64 caractères"
+                            print _("Your hostname size \
+exceeds 64 characters")
                             sys.exit(1)
+                    if self._ordres[num].split()[-1] == '-c'+linesep or \
+                        self._ordres[num].split()[-1] == '-c':
+                        break 
+
                 if boucle == 1:
                     self.interprete_ordres(num)
                     self.fin_liste_ordres(num)
@@ -170,9 +174,9 @@ dépasse 64 caractères"
                         self._premiereligne = False
                 else:
                     if port == '':
-                        self._script.append('send "ssh %s\\r"\n' % machine)
+                        self._script.append('send -- "ssh %s\\r"\n' % machine)
                     else:
-                        self._script.append('send "ssh -p %s %s\\r"\n' %
+                        self._script.append('send -- "ssh -p %s %s\\r"\n' %
                                                      (port, machine))
                 if ligne.split()[-1] == '-c':
                     self.avec_commande(ligne)
@@ -212,7 +216,7 @@ dépasse 64 caractères"
 
     def traite_commande(self, ligne):
         """Traite la commande contenue dans la ligne courante"""
-        self._script.append('send "%s\\r"\n' % ligne.rstrip(linesep))
+        self._script.append('send -- "%s\\r"\n' % ligne.rstrip(linesep))
         self.prepare_prompt()
 
     def change_utilisateur(self, utilisateur, motdepasse):
@@ -220,9 +224,9 @@ dépasse 64 caractères"
         #motdepasse = motdepasse.replace('"','\\"')
         if motdepasse in self._jetons:
             motdepasse = self._jetons[motdepasse]
-        self._script.append('send "su - %s\\r"\n' % utilisateur)
+        self._script.append('send -- "su - %s\\r"\n' % utilisateur)
         self._script.append('expect "assword:"\n')
-        self._script.append('send "%s\\r"\n' % motdepasse)
+        self._script.append('send -- "%s\\r"\n' % motdepasse)
         if utilisateur == 'root':
             self._utilisateurroot = True
         else:
@@ -241,6 +245,6 @@ dépasse 64 caractères"
         #motdepasse = motdepasse.replace('"','\\"')
         if motdepasse in self._jetons:
             motdepasse = self._jetons[motdepasse]
-        self._script.append('expect {\n "assword:" {send "%s\\r"}\n \
-"yes/no" {send "yes\\r";exp_continue}\n}\n' % motdepasse)
+        self._script.append('expect {\n "assword:" {send -- "%s\\r"}\n \
+"yes/no" {send -- "yes\\r";exp_continue}\n}\n' % motdepasse)
 
